@@ -497,8 +497,8 @@ Storage pool volume refresh events
 
 =head2 LIFECYCLE CHANGE EVENTS
 
-The following constants allow network lifecycle change events to be
-interpreted. The events contain both a state change, and a
+The following constants allow storage pool lifecycle change events
+to be interpreted. The events contain both a state change, and a
 reason though the reason is currently unsed.
 
 =over 4
@@ -506,20 +506,28 @@ reason though the reason is currently unsed.
 =item Sys::Virt::StoragePool::EVENT_DEFINED
 
 Indicates that a persistent configuration has been defined for
-the network.
+the storage pool
 
 =item Sys::Virt::StoragePool::EVENT_STARTED
 
-The network has started running
+The storage pool has started running
 
 =item Sys::Virt::StoragePool::EVENT_STOPPED
 
-The network has stopped running
+The storage pool has stopped running
 
 =item Sys::Virt::StoragePool::EVENT_UNDEFINED
 
 The persistent configuration has gone away
 
+=item Sys::Virt::StoragePool::EVENT_CREATED
+
+The underlying storage has been built
+
+=item Sys::Virt::StoragePool::EVENT_DELETED
+
+The underlying storage has been released
+
 =back
 
 =head1 AUTHORS
